unit CompInstallUnitsFrames;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms, 
  Dialogs, StdCtrls, ExtCtrls, Registry;

type
  TInstallUnitsFrame = class(TFrame)
    UnitFileNamesEdit: TLabeledEdit;
    UnitsBrowseButton: TButton;
    ExistingPackageRadio: TRadioButton;
    NewPackageRadio: TRadioButton;
    OpenUnitsDialog: TOpenDialog;
    PackagePanel: TPanel;
    procedure UnitsBrowseButtonClick(Sender: TObject);
  private
    FUnits: TStrings;
    function GetUnits: TStrings;
  public
    destructor Destroy; override;
    procedure LoadValues(Registry: TRegistry); virtual;
    procedure SaveValues(Registry: TRegistry); virtual;
    property Units: TStrings read GetUnits;
  end;

implementation

{$R *.dfm}

uses
  CompInstallConsts, CompInstallTools;

destructor TInstallUnitsFrame.Destroy;
begin
  FUnits.Free;
  inherited;
end;

function TInstallUnitsFrame.GetUnits: TStrings;
begin
  if not Assigned(FUnits) then
    FUnits := TStringList.Create;
  Result := FUnits;
end;

procedure TInstallUnitsFrame.LoadValues(Registry: TRegistry);
begin
  OpenUnitsDialog.InitialDir := Registry.ReadString(SUnitDirectory);
end;

procedure TInstallUnitsFrame.SaveValues(Registry: TRegistry);
begin
  Registry.WriteString(SUnitDirectory,
    ExtractFilePath(ExpandFileName(OpenUnitsDialog.FileName)));
end;

procedure TInstallUnitsFrame.UnitsBrowseButtonClick(Sender: TObject);
var
  I: Integer;
  S: string;
begin
  S := '';
{$IF (RTLVersion <= 18.0) and not defined(VER185)}
  if IsCppPersonality then
    OpenUnitsDialog.FilterIndex := 2;
{$IFEND}
  if OpenUnitsDialog.Execute then
  begin
    if not Assigned(FUnits) then
      FUnits := TStringList.Create;
    for I := 0 to OpenUnitsDialog.Files.Count - 1 do
    begin
      FUnits.Add(OpenUnitsDialog.Files[I]);
      S := S + '"' + ExtractFileName(OpenUnitsDialog.Files[I]) + '" ';
    end;
    UnitFileNamesEdit.Text := S;
  end;
end;

end.
